CoordMapper

Trait CoordMapper 

pub trait CoordMapper {
    type Output;

    // Required method
    fn map<CT: CoordTranslate>(
        coord_trans: &CT,
        from: &CT::From,
        rect: &Rect,
    ) -> Self::Output;
}
Useful to translate from guest coordinates to backend coordinates

Required Associated Types

type Output

Specifies the output data from the translation

Required Methods

fn map<CT: CoordTranslate>( coord_trans: &CT, from: &CT::From, rect: &Rect, ) -> Self::Output

Performs the translation from guest coordinates to backend coordinates

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors